DLC Pro Controlled Laser - Heros Devices 0.6.1 documentation

Skip to content
Back to top
View this page

# DLC Pro Controlled Laser

From: Toptica Photonics

Class: `herosdevices.hardware.toptica.dlcpro.DlcProSource`

Driver Quality Index: alpha

Reading Toptica DLC Pro parameters via ethernet.

Bold arguments are mandatory. For more information on the listed arguments refer to the class documentation: `herosdevices.hardware.toptica.dlcpro.DlcProSource` If parameters appear in this list but not in the class definition, please recursively check the linked base classes for the definition of the parameter.

Argument | Type | Default Value | Description
--- | --- | --- | ---
ip | <class ‘str’> | 127.0.0.1 |
laser | <class ‘str’> | laser1 |
queries | list[list[str]] | [[‘set current’, ‘dl.cc.current_set’, ‘mA’], [‘actual current’, ‘dl.cc.current_act’, ‘mA’], [‘set temperature’, ‘dl.tc.temp_set’, ‘degC’], [‘actual temperature’, ‘dl.tc.temp_act’, ‘degC’], [‘lock Status’, ‘dl.lock.state’, ‘’], [‘diode ontime’, ‘dl.ontime’, ‘s’], [‘system health’, ‘system_health’, ‘’], [‘laser health’, ‘health’, ‘’], [‘emission status’, ‘emission’, ‘’], [‘internal PD’, ‘dl.cc.pd’, ‘uA’]] |

This JSON string can be used to start a HERO device representation of `DlcProSource` using BOSS.

    {
        "_id": "my_DlcProSource",
        "classname": "herosdevices.hardware.toptica.dlcpro.DlcProSource",
        "arguments": {
            "ip": "127.0.0.1",
            "laser": "laser1",
            "queries": [
                [
                    "set current",
                    "dl.cc.current_set",
                    "mA"
                ],
                [
                    "actual current",
                    "dl.cc.current_act",
                    "mA"
                ],
                [
                    "set temperature",
                    "dl.tc.temp_set",
                    "degC"
                ],
                [
                    "actual temperature",
                    "dl.tc.temp_act",
                    "degC"
                ],
                [
                    "lock Status",
                    "dl.lock.state",
                    ""
                ],
                [
                    "diode ontime",
                    "dl.ontime",
                    "s"
                ],
                [
                    "system health",
                    "system_health",
                    ""
                ],
                [
                    "laser health",
                    "health",
                    ""
                ],
                [
                    "emission status",
                    "emission",
                    ""
                ],
                [
                    "internal PD",
                    "dl.cc.pd",
                    "uA"
                ]
            ]
        }
    }